==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="30"/>
        <source>Print playback status</source>
        <translation>Weergeef speelstatus</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="31"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>Weergeef geformateerde nummertitel (voorbeeld: qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="33"/>
        <source>Print --nowplaying syntax</source>
        <translation>Weergeef --nowplaying syntax</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>Syntax:</source>
        <translation>Syntax:</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%p - artist</source>
        <translation>%p - artiest</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%a - album</source>
        <translation>%a - album</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%aa - album artist</source>
        <translation>%aa - albumartiest</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%t - title</source>
        <translation>%t - titel</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%n - track</source>
        <translation>%n - liednummer</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN - liednummer (twee cijfer formaat)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%g - genre</source>
        <translation>%g - genre</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%c - comment</source>
        <translation>%c - commentaar</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%C - composer</source>
        <translation>%C - componist</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="104"/>
        <source>%D - disc number</source>
        <translation>%D - CD nummer</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="105"/>
        <source>%f - file name</source>
        <translation>%f - bestandsnaam</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="106"/>
        <source>%F - full path</source>
        <translation>%F - volledig pad</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="107"/>
        <source>%y - year</source>
        <translation>%y - jaar</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="108"/>
        <source>%l - duration</source>
        <translation>%I - duur</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="109"/>
        <source>%{bitrate} - bitrate</source>
        <translation>%{bitrate} - bitsnelheid</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="110"/>
        <source>%{samplerate} - sample rate</source>
        <translation>%{samplerate} - samplesnelheid</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="111"/>
        <source>%{channels} - number of channels</source>
        <translation>%{channels} - aantal kanalen</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="112"/>
        <source>%{samplesize} - bits per sample</source>
        <translation>%{samplesize} - bits per sample</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="113"/>
        <source>%{format} - format name</source>
        <translation>%{format} - naaw van bestandformaat</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="114"/>
        <source>%{decoder} - decoder name</source>
        <translation>%{decoder} - naam van decoder</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="115"/>
        <source>%{filesize} - file size</source>
        <translation>%{filesize} - bestandsgrootte</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="116"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) - conditie</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="117"/>
        <source>%dir(n) - directory name located on n levels above</source>
        <translation>%dir(n) - mapnaam, x aantal bovenliggend</translation>
    </message>
</context>
</TS>

==> qmmp_1.0.5.orig.tar.bz2: qmmp-1.0.5/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="39"/>
        <source>Print playback status</source>
        <translation>Weergeef speelstatus</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="41"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>Weergeef geformateerde nummertitel (voorbeeld: qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="42"/>
        <source>Print --nowplaying syntax</source>
        <translation>Weergeef --nowplaying syntax</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="89"/>
        <source>Syntax:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="90"/>
        <source>%p - artist</source>
        <translation>%p - artiest</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="91"/>
        <source>%a - album</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="92"/>
        <source>%aa - album artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="93"/>
        <source>%t - title</source>
        <translation>%t - titel</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>%n - track</source>
        <translation>%n - liednummer</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN - liednummer (twee cijfer formaat)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%g - genre</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%c - comment</source>
        <translation>%c - commentaar</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%C - composer</source>
        <translation>%C - componist</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%D - disc number</source>
        <translation>%D - CD nummer</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%f - file name</source>
        <translation>%f - bestandsnaam</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%F - full path</source>
        <translation>%F - volledig pad</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%y - year</source>
        <translation>%y - jaar</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%l - duration</source>
        <translation>%I - duur</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="104"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) - conditie</translation>
    </message>
</context>
</TS>
